import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataTlsCertificateConfig extends cdktf.TerraformMetaArguments {
    /**
    * URL of the endpoint to get the certificates from. Accepted schemes are: `https`, `tls`. For scheme `https://` it will use the HTTP protocol and apply the `proxy` configuration of the provider, if set. For scheme `tls://` it will instead use a secure TCP socket.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tls/d/certificate#url DataTlsCertificate#url}
    */
    readonly url: string;
    /**
    * Whether to verify the certificate chain while parsing it or not (default: `true`).
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tls/d/certificate#verify_chain DataTlsCertificate#verify_chain}
    */
    readonly verifyChain?: boolean | cdktf.IResolvable;
}
export interface DataTlsCertificateCertificates {
}
export declare function dataTlsCertificateCertificatesToTerraform(struct?: DataTlsCertificateCertificates): any;
export declare class DataTlsCertificateCertificatesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataTlsCertificateCertificates | undefined;
    set internalValue(value: DataTlsCertificateCertificates | undefined);
    get isCa(): cdktf.IResolvable;
    get issuer(): string;
    get notAfter(): string;
    get notBefore(): string;
    get publicKeyAlgorithm(): string;
    get serialNumber(): string;
    get sha1Fingerprint(): string;
    get signatureAlgorithm(): string;
    get subject(): string;
    get version(): number;
}
export declare class DataTlsCertificateCertificatesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataTlsCertificateCertificatesOutputReference;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/tls/d/certificate tls_certificate}
*/
export declare class DataTlsCertificate extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "tls_certificate";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/tls/d/certificate tls_certificate} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataTlsCertificateConfig
    */
    constructor(scope: Construct, id: string, config: DataTlsCertificateConfig);
    private _certificates;
    get certificates(): DataTlsCertificateCertificatesList;
    get id(): string;
    private _url?;
    get url(): string;
    set url(value: string);
    get urlInput(): string | undefined;
    private _verifyChain?;
    get verifyChain(): boolean | cdktf.IResolvable;
    set verifyChain(value: boolean | cdktf.IResolvable);
    resetVerifyChain(): void;
    get verifyChainInput(): boolean | cdktf.IResolvable | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
